==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/industrial_protocol_docs/am64x/ethercat_slave/struct_e_c___s_l_v___a_p_p___sapplication.js <==
var struct_e_c___s_l_v___a_p_p___sapplication =
[
    [ "selectedPruInstance", "struct_e_c___s_l_v___a_p_p___sapplication_ab6530e619c5714155076c713f18bbaca.html#ab6530e619c5714155076c713f18bbaca", null ],
    [ "mainThreadHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a09cf8f76beea3cfbde3cf51aac38cddc.html#a09cf8f76beea3cfbde3cf51aac38cddc", null ],
    [ "loopThreadHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a2d2192de53095e6f0b99f48ec007e0bf.html#a2d2192de53095e6f0b99f48ec007e0bf", null ],
    [ "gpioHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a90d8a4822e0a181a08abc63792f77a6c.html#a90d8a4822e0a181a08abc63792f77a6c", null ],
    [ "remoteHandle", "struct_e_c___s_l_v___a_p_p___sapplication_aa73d06a4594bc0846187224dd53de98a.html#aa73d06a4594bc0846187224dd53de98a", null ],
    [ "ioexpLedHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a2772ce94c47440d9a016f308a6c3ecd9.html#a2772ce94c47440d9a016f308a6c3ecd9", null ],
    [ "msec", "struct_e_c___s_l_v___a_p_p___sapplication_adfd6f7d5c38fe7a5840bb7ec7aba2b28.html#adfd6f7d5c38fe7a5840bb7ec7aba2b28", null ],
    [ "trigger", "struct_e_c___s_l_v___a_p_p___sapplication_a623422ddf2d23f81cda527a3df9b9658.html#a623422ddf2d23f81cda527a3df9b9658", null ],
    [ "state", "struct_e_c___s_l_v___a_p_p___sapplication_a0b57aa10271a66f3dc936bba1d2f3830.html#a0b57aa10271a66f3dc936bba1d2f3830", null ],
    [ "rsvd", "struct_e_c___s_l_v___a_p_p___sapplication_aad7157e0fe920ef2330a54b72fa978dc.html#aad7157e0fe920ef2330a54b72fa978dc", null ],
    [ "prev", "struct_e_c___s_l_v___a_p_p___sapplication_ae6dc592928246b049bb7c47ca4f5d5f9.html#ae6dc592928246b049bb7c47ca4f5d5f9", null ],
    [ "diff", "struct_e_c___s_l_v___a_p_p___sapplication_a198b00331e2bf9e4d59b637c8401069e.html#a198b00331e2bf9e4d59b637c8401069e", null ],
    [ "ptRecObjOut", "struct_e_c___s_l_v___a_p_p___sapplication_aba41fc93f0752131f99d505a3a629505.html#aba41fc93f0752131f99d505a3a629505", null ],
    [ "pt2002RecObj", "struct_e_c___s_l_v___a_p_p___sapplication_ad890e227219e7f96be93328c5939522e.html#ad890e227219e7f96be93328c5939522e", null ],
    [ "pt2007RecObj", "struct_e_c___s_l_v___a_p_p___sapplication_a4da75433638830ade293fb36d6ebc729.html#a4da75433638830ade293fb36d6ebc729", null ],
    [ "pt200FRecObj", "struct_e_c___s_l_v___a_p_p___sapplication_a6389f0bc0d26f19ba28c7caa134a573c.html#a6389f0bc0d26f19ba28c7caa134a573c", null ],
    [ "ptRxPdo1600", "struct_e_c___s_l_v___a_p_p___sapplication_a339229f47aba8bb1c64ca575d4d387dd.html#a339229f47aba8bb1c64ca575d4d387dd", null ],
    [ "ptRxPdo1601", "struct_e_c___s_l_v___a_p_p___sapplication_a06a2a505822dfe9bc8c4730b56b22e70.html#a06a2a505822dfe9bc8c4730b56b22e70", null ],
    [ "ptTxPdo1A00", "struct_e_c___s_l_v___a_p_p___sapplication_afdffe989c929ce523847ea8138af61bf.html#afdffe989c929ce523847ea8138af61bf", null ],
    [ "ptTxPdo1A01", "struct_e_c___s_l_v___a_p_p___sapplication_ae234681f48cb35ab6e29a5a0da4ee23d.html#ae234681f48cb35ab6e29a5a0da4ee23d", null ],
    [ "ptEcSlvApi", "struct_e_c___s_l_v___a_p_p___sapplication_aba7a74308b602719ff87c64b863bcf2e.html#aba7a74308b602719ff87c64b863bcf2e", null ],
    [ "ptRxPdo1602", "struct_e_c___s_l_v___a_p_p___sapplication_aa14d3b249f84c6438cf39c60f135e9bf.html#aa14d3b249f84c6438cf39c60f135e9bf", null ],
    [ "ptTxPdo1A02", "struct_e_c___s_l_v___a_p_p___sapplication_a069df9037d75dea8a5e97523f0378380.html#a069df9037d75dea8a5e97523f0378380", null ]
];

==> mcu_plus_sdk_am64x_08_01_00_36_docs_only.tar.xz: mcu_plus_sdk_am64x_08_01_00_36_docs_only/docs/industrial_protocol_docs/am64x/ethercat_slave/struct_e_c___s_l_v___a_p_p___sapplication.js <==
var struct_e_c___s_l_v___a_p_p___sapplication =
[
    [ "selectedPruInstance", "struct_e_c___s_l_v___a_p_p___sapplication_ab6530e619c5714155076c713f18bbaca.html#ab6530e619c5714155076c713f18bbaca", null ],
    [ "mainThreadHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a09cf8f76beea3cfbde3cf51aac38cddc.html#a09cf8f76beea3cfbde3cf51aac38cddc", null ],
    [ "loopThreadHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a2d2192de53095e6f0b99f48ec007e0bf.html#a2d2192de53095e6f0b99f48ec007e0bf", null ],
    [ "gpioHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a90d8a4822e0a181a08abc63792f77a6c.html#a90d8a4822e0a181a08abc63792f77a6c", null ],
    [ "remoteHandle", "struct_e_c___s_l_v___a_p_p___sapplication_aa73d06a4594bc0846187224dd53de98a.html#aa73d06a4594bc0846187224dd53de98a", null ],
    [ "ioexpLedHandle", "struct_e_c___s_l_v___a_p_p___sapplication_a2772ce94c47440d9a016f308a6c3ecd9.html#a2772ce94c47440d9a016f308a6c3ecd9", null ],
    [ "msec", "struct_e_c___s_l_v___a_p_p___sapplication_adfd6f7d5c38fe7a5840bb7ec7aba2b28.html#adfd6f7d5c38fe7a5840bb7ec7aba2b28", null ],
    [ "trigger", "struct_e_c___s_l_v___a_p_p___sapplication_a623422ddf2d23f81cda527a3df9b9658.html#a623422ddf2d23f81cda527a3df9b9658", null ],
    [ "state", "struct_e_c___s_l_v___a_p_p___sapplication_a0b57aa10271a66f3dc936bba1d2f3830.html#a0b57aa10271a66f3dc936bba1d2f3830", null ],
    [ "rsvd", "struct_e_c___s_l_v___a_p_p___sapplication_aad7157e0fe920ef2330a54b72fa978dc.html#aad7157e0fe920ef2330a54b72fa978dc", null ],
    [ "prev", "struct_e_c___s_l_v___a_p_p___sapplication_ae6dc592928246b049bb7c47ca4f5d5f9.html#ae6dc592928246b049bb7c47ca4f5d5f9", null ],
    [ "diff", "struct_e_c___s_l_v___a_p_p___sapplication_a198b00331e2bf9e4d59b637c8401069e.html#a198b00331e2bf9e4d59b637c8401069e", null ],
    [ "ptRecObjOut", "struct_e_c___s_l_v___a_p_p___sapplication_aba41fc93f0752131f99d505a3a629505.html#aba41fc93f0752131f99d505a3a629505", null ],
    [ "pt2002RecObj", "struct_e_c___s_l_v___a_p_p___sapplication_ad890e227219e7f96be93328c5939522e.html#ad890e227219e7f96be93328c5939522e", null ],
    [ "pt2007RecObj", "struct_e_c___s_l_v___a_p_p___sapplication_a4da75433638830ade293fb36d6ebc729.html#a4da75433638830ade293fb36d6ebc729", null ],
    [ "pt200FRecObj", "struct_e_c___s_l_v___a_p_p___sapplication_a6389f0bc0d26f19ba28c7caa134a573c.html#a6389f0bc0d26f19ba28c7caa134a573c", null ],
    [ "ptRxPdo1600", "struct_e_c___s_l_v___a_p_p___sapplication_a339229f47aba8bb1c64ca575d4d387dd.html#a339229f47aba8bb1c64ca575d4d387dd", null ],
    [ "ptRxPdo1601", "struct_e_c___s_l_v___a_p_p___sapplication_a06a2a505822dfe9bc8c4730b56b22e70.html#a06a2a505822dfe9bc8c4730b56b22e70", null ],
    [ "ptTxPdo1A00", "struct_e_c___s_l_v___a_p_p___sapplication_afdffe989c929ce523847ea8138af61bf.html#afdffe989c929ce523847ea8138af61bf", null ],
    [ "ptTxPdo1A01", "struct_e_c___s_l_v___a_p_p___sapplication_ae234681f48cb35ab6e29a5a0da4ee23d.html#ae234681f48cb35ab6e29a5a0da4ee23d", null ],
    [ "ptEcSlvApi", "struct_e_c___s_l_v___a_p_p___sapplication_aba7a74308b602719ff87c64b863bcf2e.html#aba7a74308b602719ff87c64b863bcf2e", null ],
    [ "pdBuffer", "struct_e_c___s_l_v___a_p_p___sapplication_a50ee706e577a84fe815b553e2e802006.html#a50ee706e577a84fe815b553e2e802006", null ],
    [ "ptRxPdo1602", "struct_e_c___s_l_v___a_p_p___sapplication_aa14d3b249f84c6438cf39c60f135e9bf.html#aa14d3b249f84c6438cf39c60f135e9bf", null ],
    [ "ptTxPdo1A02", "struct_e_c___s_l_v___a_p_p___sapplication_a069df9037d75dea8a5e97523f0378380.html#a069df9037d75dea8a5e97523f0378380", null ],
    [ "pdoOutLen", "struct_e_c___s_l_v___a_p_p___sapplication_a50d35a8a120dba883ca47eac66d8a031.html#a50d35a8a120dba883ca47eac66d8a031", null ],
    [ "pdoInLen", "struct_e_c___s_l_v___a_p_p___sapplication_ab5a1d61066d86bb7b58a4ca6a0fbd9c6.html#ab5a1d61066d86bb7b58a4ca6a0fbd9c6", null ],
    [ "pdRxBuffer", "struct_e_c___s_l_v___a_p_p___sapplication_a23ab3904e15ab88122aee8d196909d47.html#a23ab3904e15ab88122aee8d196909d47", null ],
    [ "pdTxBuffer", "struct_e_c___s_l_v___a_p_p___sapplication_a5aaa79ed2f0b5f93830f784d2ee7fd41.html#a5aaa79ed2f0b5f93830f784d2ee7fd41", null ],
    [ "realPdoOutLen", "struct_e_c___s_l_v___a_p_p___sapplication_a1a16e4aa70171b44d5c5ccc614ef6939.html#a1a16e4aa70171b44d5c5ccc614ef6939", null ],
    [ "realPdoInLen", "struct_e_c___s_l_v___a_p_p___sapplication_a8f0ace010210b60edb96478c346f5a69.html#a8f0ace010210b60edb96478c346f5a69", null ],
    [ "CiA402_axisData", "struct_e_c___s_l_v___a_p_p___sapplication_af0344da09f89773b2fb0d96d61a94210.html#af0344da09f89773b2fb0d96d61a94210", null ]
];
